@@ -146,7 +146,8 @@ namespace pika::drop_op_state_detail {
             pika::execution::experimental::start_t, drop_op_state_op_state_type& os) noexcept
         {
             PIKA_ASSERT(os.op_state.has_value());
-            pika::execution::experimental::start(os.op_state.value());
+            // NOLINTNEXTLINE(bugprone-unchecked-optional-access)
+            pika::execution::experimental::start(*(os.op_state));
         }
     };
 
@@ -238,12 +239,12 @@ namespace pika::execution::experimental {
     inline constexpr struct drop_operation_state_t final
     {
         template <typename Sender, PIKA_CONCEPT_REQUIRES_(is_sender_v<Sender>)>
-        constexpr PIKA_FORCEINLINE auto operator()(Sender&& sender) const
+        constexpr PIKA_FORCEINLINE auto PIKA_STATIC_CALL_OPERATOR(Sender&& sender)
         {
             return drop_op_state_detail::drop_op_state_sender<Sender>{PIKA_FORWARD(Sender, sender)};
         }
 
-        constexpr PIKA_FORCEINLINE auto operator()() const
+        constexpr PIKA_FORCEINLINE auto PIKA_STATIC_CALL_OPERATOR()
         {
             return detail::partial_algorithm<drop_operation_state_t>{};
         }
