@@ -292,12 +292,12 @@ namespace pika::ensure_started_detail {
                     // the vector must see predecessor_done = true after
                     // taking the lock in their threads and will not add
                     // continuations to the vector.
-                    std::unique_lock<mutex_type> l{mtx};
+                    std::lock_guard<mutex_type> l{mtx};
                 }
 
                 if (continuation)
                 {
-                    continuation.value()();
+                    (*continuation)();
                     continuation.reset();
                 }
             }
@@ -360,7 +360,7 @@ namespace pika::ensure_started_detail {
                 if (!start_called.exchange(true))
                 {
                     PIKA_ASSERT(os.has_value());
-                    pika::execution::experimental::start(os.value());
+                    pika::execution::experimental::start(*os);
                 }
             }
 
