@@ -22,20 +22,14 @@ bool value_called = false;
 namespace mylib {
     struct receiver_1
     {
-        friend void tag_invoke(ex::set_stopped_t, receiver_1&&) noexcept
-        {
-            done_called = true;
-        }
+        friend void tag_invoke(ex::set_stopped_t, receiver_1&&) noexcept { done_called = true; }
 
         friend void tag_invoke(ex::set_error_t, receiver_1&&, std::exception_ptr) noexcept
         {
             error_called = true;
         }
 
-        friend void tag_invoke(ex::set_value_t, receiver_1&&, int) noexcept
-        {
-            value_called = true;
-        }
+        friend void tag_invoke(ex::set_value_t, receiver_1&&, int) noexcept { value_called = true; }
 
         friend constexpr ex::empty_env tag_invoke(ex::get_env_t, receiver_1 const&) noexcept
         {
@@ -45,15 +39,9 @@ namespace mylib {
 
     struct receiver_2
     {
-        friend void tag_invoke(ex::set_stopped_t, receiver_2&&) noexcept
-        {
-            done_called = true;
-        }
+        friend void tag_invoke(ex::set_stopped_t, receiver_2&&) noexcept { done_called = true; }
 
-        friend void tag_invoke(ex::set_error_t, receiver_2&&, int) noexcept
-        {
-            error_called = true;
-        }
+        friend void tag_invoke(ex::set_error_t, receiver_2&&, int) noexcept { error_called = true; }
 
         friend constexpr ex::empty_env tag_invoke(ex::get_env_t, receiver_2 const&) noexcept
         {
@@ -63,20 +51,14 @@ namespace mylib {
 
     struct receiver_3
     {
-        friend void tag_invoke(ex::set_stopped_t, receiver_3&&) noexcept
-        {
-            done_called = true;
-        }
+        friend void tag_invoke(ex::set_stopped_t, receiver_3&&) noexcept { done_called = true; }
 
         friend void tag_invoke(ex::set_error_t, receiver_3&&, std::exception_ptr) noexcept
         {
             error_called = true;
         }
 
-        friend void tag_invoke(ex::set_value_t, receiver_3, int) noexcept
-        {
-            value_called = true;
-        }
+        friend void tag_invoke(ex::set_value_t, receiver_3, int) noexcept { value_called = true; }
 
         friend constexpr ex::empty_env tag_invoke(ex::get_env_t, receiver_3 const&) noexcept
         {
@@ -86,10 +68,7 @@ namespace mylib {
 
     struct non_receiver_1
     {
-        friend void tag_invoke(ex::set_stopped_t, non_receiver_1&) noexcept
-        {
-            done_called = true;
-        }
+        friend void tag_invoke(ex::set_stopped_t, non_receiver_1&) noexcept { done_called = true; }
 
         friend void tag_invoke(ex::set_error_t, non_receiver_1&&, std::exception_ptr) noexcept
         {
@@ -104,10 +83,7 @@ namespace mylib {
 
     struct non_receiver_2
     {
-        friend void tag_invoke(ex::set_stopped_t, non_receiver_2&&) noexcept
-        {
-            done_called = true;
-        }
+        friend void tag_invoke(ex::set_stopped_t, non_receiver_2&&) noexcept { done_called = true; }
 
         friend void tag_invoke(ex::set_error_t, non_receiver_2&, std::exception_ptr) noexcept
         {
@@ -122,10 +98,7 @@ namespace mylib {
 
     struct non_receiver_3
     {
-        friend void tag_invoke(ex::set_stopped_t, non_receiver_3&) noexcept
-        {
-            done_called = true;
-        }
+        friend void tag_invoke(ex::set_stopped_t, non_receiver_3&) noexcept { done_called = true; }
 
         friend void tag_invoke(ex::set_error_t, non_receiver_3&, std::exception_ptr) noexcept
         {
@@ -140,10 +113,7 @@ namespace mylib {
 
     struct non_receiver_4
     {
-        friend void tag_invoke(ex::set_stopped_t, non_receiver_4&&) noexcept
-        {
-            done_called = true;
-        }
+        friend void tag_invoke(ex::set_stopped_t, non_receiver_4&&) noexcept { done_called = true; }
 
         friend void tag_invoke(ex::set_error_t, non_receiver_4&&, std::exception_ptr) noexcept
         {
@@ -163,10 +133,7 @@ namespace mylib {
 
     struct non_receiver_5
     {
-        friend void tag_invoke(ex::set_stopped_t, non_receiver_5&&)
-        {
-            done_called = true;
-        }
+        friend void tag_invoke(ex::set_stopped_t, non_receiver_5&&) { done_called = true; }
 
         friend void tag_invoke(ex::set_error_t, non_receiver_5&&, std::exception_ptr) noexcept
         {
@@ -176,10 +143,7 @@ namespace mylib {
 
     struct non_receiver_6
     {
-        friend void tag_invoke(ex::set_stopped_t, non_receiver_6&&) noexcept
-        {
-            done_called = true;
-        }
+        friend void tag_invoke(ex::set_stopped_t, non_receiver_6&&) noexcept { done_called = true; }
 
         friend void tag_invoke(ex::set_error_t, non_receiver_6&&, std::exception_ptr)
         {
@@ -189,10 +153,7 @@ namespace mylib {
 
     struct non_receiver_7
     {
-        friend void tag_invoke(ex::set_stopped_t, non_receiver_7&&)
-        {
-            done_called = true;
-        }
+        friend void tag_invoke(ex::set_stopped_t, non_receiver_7&&) { done_called = true; }
 
         friend void tag_invoke(ex::set_error_t, non_receiver_7&&, std::exception_ptr)
         {
