@@ -16,6 +16,7 @@
 # include <cmath>
 # include <cstddef>
 # include <cstdint>
+# include <cstdlib>
 # include <iostream>
 # include <memory>
 # include <set>
@@ -28,6 +29,9 @@
 // NB
 // this test needs to be updated as it no longer does what it is supposed to do
 
+namespace ex = pika::execution::experimental;
+namespace tt = pika::this_thread::experimental;
+
 namespace resource::pools {
     enum ids
     {
@@ -47,7 +51,7 @@ using high_priority_sched = pika::threads::detail::shared_priority_queue_schedul
 using namespace pika::threads;
 using pika::threads::scheduler_mode;
 
-// dummy function we will call using async
+// dummy function we will call using then
 void do_stuff(std::size_t n, bool printout)
 {
     if (printout) std::cout << "[do stuff] " << n << "\n";
@@ -75,21 +79,21 @@ int pika_main(/*pika::program_options::variables_map& vm*/)
     std::size_t loop_count = num_threads * 1;
     std::size_t async_count = num_threads * 1;
 
-    // create an executor with high priority for important tasks
-    pika::execution::parallel_executor high_priority_executor(
-        pika::this_thread::get_pool(), pika::execution::thread_priority::high_recursive);
-    pika::execution::parallel_executor normal_priority_executor;
+    // create a scheduler with high priority for important tasks
+    auto high_priority_scheduler =
+        ex::with_priority(ex::thread_pool_scheduler{pika::this_thread::get_pool()},
+            pika::execution::thread_priority::high_recursive);
+    auto normal_priority_scheduler = ex::thread_pool_scheduler{pika::this_thread::get_pool()};
 
-    pika::execution::parallel_executor pool_executor;
-    // create an executor on the mpi pool
+    ex::thread_pool_scheduler pool_scheduler;
+    // create a scheduler on the mpi pool
     if (use_pools)
     {
-        // get executors
-        pool_executor =
-            pika::execution::parallel_executor(&pika::resource::get_thread_pool(pool_name));
-        std::cout << "\n[pika_main] got mpi executor " << std::endl;
+        // get schedulers
+        pool_scheduler = ex::thread_pool_scheduler{&pika::resource::get_thread_pool(pool_name)};
+        std::cout << "\n[pika_main] got mpi scheduler " << std::endl;
     }
-    else { pool_executor = high_priority_executor; }
+    else { pool_scheduler = high_priority_scheduler; }
 
     // print partition characteristics
     std::cout << "\n\n[pika_main] print resource_partitioner characteristics : "
@@ -104,92 +108,93 @@ int pika_main(/*pika::program_options::variables_map& vm*/)
     // print system characteristics
     print_system_characteristics();
 
-    // use executor to schedule work on custom pool
-    pika::future<void> future_1 = pika::async(pool_executor, &do_stuff, 5, true);
-
-    pika::future<void> future_2 =
-        future_1.then(pool_executor, [](pika::future<void>&&) { do_stuff(5, true); });
-
-    pika::future<void> future_3 = future_2.then(pool_executor,
-        [pool_executor, high_priority_executor, async_count](pika::future<void>&&) mutable {
-            pika::future<void> future_4, future_5;
+    // use scheduler to schedule work on custom pool
+    auto sender = ex::schedule(pool_scheduler) |
+        ex::then(pika::util::detail::bind_front(do_stuff, 5, true)) | ex::transfer(pool_scheduler) |
+        ex::then([]() { do_stuff(5, true); }) | ex::transfer(pool_scheduler) |
+        ex::then([pool_scheduler, high_priority_scheduler, async_count]() mutable {
+            ex::unique_any_sender<> sender1, sender2;
             for (std::size_t i = 0; i < async_count; i++)
             {
                 if (i % 2 == 0)
                 {
-                    future_4 = pika::async(pool_executor, &do_stuff, async_count, false);
+                    sender1 = ex::schedule(pool_scheduler) |
+                        ex::then(pika::util::detail::bind_front(&do_stuff, async_count, false));
                 }
                 else
                 {
-                    future_5 = pika::async(high_priority_executor, &do_stuff, async_count, false);
+                    sender2 = ex::schedule(high_priority_scheduler) |
+                        ex::then(pika::util::detail::bind_front(&do_stuff, async_count, false));
                 }
             }
-            // the last futures we made are stored in here
-            future_4.get();
-            future_5.get();
+
+            // the last senders we made are stored in here
+            tt::sync_wait(std::move(sender1));
+            tt::sync_wait(std::move(sender2));
         });
 
-    future_3.get();
+    tt::sync_wait(std::move(sender));
 
     pika::mutex m;
     std::set<std::thread::id> thread_set;
-    std::vector<pika::future<void>> futures;
+    std::vector<ex::unique_any_sender<>> senders;
 
     // launch tasks on custom pool with high priority
     for (std::size_t i = 0; i < loop_count; ++i)
     {
-        futures.push_back(pika::async(high_priority_executor, [&, i]() {
+        senders.push_back(ex::schedule(high_priority_scheduler) | ex::then([&, i]() {
             std::lock_guard<pika::mutex> lock(m);
             if (thread_set.insert(std::this_thread::get_id()).second)
             {
                 std::cout << std::hex << pika::this_thread::get_id() << " " << std::hex
-                          << std::this_thread::get_id() << " high priority executor i " << std::dec
+                          << std::this_thread::get_id() << " high priority scheduler i " << std::dec
                           << i << std::endl;
             }
         }));
     }
-    pika::wait_all(std::move(futures));
+    tt::sync_wait(ex::when_all_vector(std::move(senders)));
     std::cout << "thread set contains " << std::dec << thread_set.size() << std::endl;
-    futures.clear();
+    senders.clear();
     thread_set.clear();
 
     // launch tasks on custom pool with normal priority
     for (std::size_t i = 0; i < loop_count; ++i)
     {
-        futures.push_back(pika::async(normal_priority_executor, [&, i]() {
+        senders.push_back(ex::schedule(normal_priority_scheduler) | ex::then([&, i]() {
             std::lock_guard<pika::mutex> lock(m);
             if (thread_set.insert(std::this_thread::get_id()).second)
             {
                 std::cout << std::hex << pika::this_thread::get_id() << " " << std::hex
-                          << std::this_thread::get_id() << " normal priority executor i "
+                          << std::this_thread::get_id() << " normal priority scheduler i "
                           << std::dec << i << std::endl;
             }
         }));
     }
-    pika::wait_all(std::move(futures));
+    tt::sync_wait(ex::when_all_vector(std::move(senders)));
     std::cout << "thread set contains " << std::dec << thread_set.size() << std::endl;
-    futures.clear();
+    senders.clear();
     thread_set.clear();
 
-    // test a parallel algorithm on pool_executor
+    // test a parallel algorithm on pool_scheduler
     for (std::size_t i = 0; i < loop_count; ++i)
     {
-        futures.push_back(pika::async(pool_executor, [&, i]() {
+        senders.push_back(ex::schedule(pool_scheduler) | ex::then([&, i]() {
             std::lock_guard<pika::mutex> lock(m);
             if (thread_set.insert(std::this_thread::get_id()).second)
             {
                 std::cout << std::hex << pika::this_thread::get_id() << " " << std::hex
-                          << std::this_thread::get_id() << " pool executor i " << std::dec << i
+                          << std::this_thread::get_id() << " pool scheduler i " << std::dec << i
                           << std::endl;
             }
         }));
     }
-    pika::wait_all(std::move(futures));
+    tt::sync_wait(ex::when_all_vector(std::move(senders)));
     std::cout << "thread set contains " << std::dec << thread_set.size() << std::endl;
-    futures.clear();
+    senders.clear();
     thread_set.clear();
 
-    return pika::finalize();
+    pika::finalize();
+    return EXIT_SUCCESS;
 }
 
 // -------------------------------------------------------------------------
@@ -238,7 +243,7 @@ int main(int argc, char* argv[])
     // clang-format off
     pika::program_options::options_description desc_cmdline("Test options");
     desc_cmdline.add_options()
-        ("use-pools,u", "Enable advanced pika thread pools and executors")
+        ("use-pools,u", "Enable advanced pika thread pools and schedulers")
         ("use-scheduler,s", "Enable custom priority scheduler")
         ("pool-threads,m", pika::program_options::value<int>()->default_value(1),
             "Number of threads to assign to custom pool");
