@@ -34,19 +34,11 @@
 ///////////////////////////////////////////////////////////////////////////////
 namespace pika::threads::detail {
     ///////////////////////////////////////////////////////////////////////////
-#if defined(PIKA_HAVE_CXX11_STD_ATOMIC_128BIT)
-    using default_static_queue_scheduler_terminated_queue = lockfree_lifo;
-#else
-    using default_static_queue_scheduler_terminated_queue = lockfree_fifo;
-#endif
-
-    ///////////////////////////////////////////////////////////////////////////
     /// The local_queue_scheduler maintains exactly one queue of work
     /// items (threads) per OS thread, where this OS thread pulls its next work
     /// from.
     template <typename Mutex = std::mutex, typename PendingQueuing = lockfree_fifo,
-        typename StagedQueuing = lockfree_fifo,
-        typename TerminatedQueuing = default_static_queue_scheduler_terminated_queue>
+        typename StagedQueuing = lockfree_fifo, typename TerminatedQueuing = lockfree_fifo>
     class static_queue_scheduler
       : public local_queue_scheduler<Mutex, PendingQueuing, StagedQueuing, TerminatedQueuing>
     {
