@@ -36,54 +36,6 @@
 #include <pika/config/warnings_prefix.hpp>
 
 namespace pika::threads::detail {
-    /// \brief Data structure which stores statistics collected by an
-    ///        executor instance.
-    struct executor_statistics
-    {
-        executor_statistics()
-          : tasks_scheduled_(0)
-          , tasks_completed_(0)
-          , queue_length_(0)
-        {
-        }
-
-        std::uint64_t tasks_scheduled_;
-        std::uint64_t tasks_completed_;
-        std::uint64_t queue_length_;
-    };
-
-    ///////////////////////////////////////////////////////////////////////
-    enum executor_parameter
-    {
-        min_concurrency = 1,
-        max_concurrency = 2,
-        current_concurrency = 3
-    };
-
-    ///////////////////////////////////////////////////////////////////////
-    // The interface below is used by the resource manager to
-    // interact with the executor.
-    struct PIKA_EXPORT manage_executor
-    {
-        virtual ~manage_executor() {}
-
-        // Return the requested policy element
-        virtual std::size_t get_policy_element(executor_parameter p, error_code& ec) const = 0;
-
-        // Return statistics collected by this scheduler
-        virtual void get_statistics(executor_statistics& stats, error_code& ec) const = 0;
-
-        // Provide the given processing unit to the scheduler.
-        virtual void add_processing_unit(
-            std::size_t virt_core, std::size_t thread_num, error_code& ec) = 0;
-
-        // Remove the given processing unit from the scheduler.
-        virtual void remove_processing_unit(std::size_t thread_num, error_code& ec) = 0;
-
-        // return the description string of the underlying scheduler
-        virtual char const* get_description() const = 0;
-    };
-
     ///////////////////////////////////////////////////////////////////////////
     /// \cond NOINTERNAL
     struct pool_id_type
@@ -105,7 +57,7 @@ namespace pika::threads::detail {
 
     struct thread_pool_init_parameters
     {
-        std::string const& name_;
+        std::string name_;
         std::size_t index_;
         scheduler_mode mode_;
         std::size_t num_threads_;
